clc; % clear command window

%% loading data from excel

Iv_c1 = readmatrix("mesh\Iv_Mesh-2a.xlsx"); % loading the measured current data
Ud_c1 = readmatrix("mesh\Ud_Mesh-2a.xlsx"); % loading the measured dc-voltage data
Uab_c1 = readmatrix("mesh\Uab_Mesh-2a.xlsx"); % loading the measured conv. op. voltage
Uout_c1 = readmatrix("mesh\Uout_Mesh-2a.xlsx"); % loading the measured load voltage

Iv_c2 = readmatrix("mesh\Iv_Mesh-2b.xlsx"); % loading the measured current data
Ud_c2 = readmatrix("mesh\Ud_Mesh-2b.xlsx"); % loading the measured dc-voltage data
Uab_c2 = readmatrix("mesh\Uab_Mesh-2b.xlsx"); % loading the measured conv. op. voltage
Uout_c2 = readmatrix("mesh\Uout_Mesh-2b.xlsx"); % loading the measured load voltage

%% plots

figure(10); clf;

tiledlayout(3,2);
textwidth = 14.9;
texthight = 18;
figsize = [textwidth, texthight];

%%% Iv plot
ax(1) = nexttile; % case 1
plot(Iv_c1(:,1), Iv_c1(:,2));
ylabel('$i_v(t)$ [A]','Interpreter','latex');
title('\bf $m_a = 0.9$','Interpreter','latex');
box off;

ax(2) = nexttile; % case 2
plot(Iv_c2(:,1), Iv_c2(:,2));
title('\bf $m_a = 0.5$','Interpreter','latex');
box off;

%%% Uab plot
ax(3) = nexttile; % case 1
plot(Uab_c1(:,1), Uab_c1(:,2));
ylabel('$u_{ab}(t)$ [V]','Interpreter','latex');
box off;

ax(4) = nexttile; % case 2
plot(Uab_c2(:,1), Uab_c2(:,2));
box off;

%%% Uout plot
ax(5) = nexttile; % case 1
plot(Uout_c1(:,1), Uout_c1(:,2)); 
ylabel('$u_{out}(t)$ [V]','Interpreter','latex');
xlabel('$t$ [s]','Interpreter','latex');
box off;

ax(6) = nexttile; % case 2
plot(Uout_c2(:,1), Uout_c2(:,2));
xlabel('$t$ [s]','Interpreter','latex');
box off;

% linking axes
linkaxes(ax(1:2),'y');
linkaxes(ax(3:4),'y');
linkaxes(ax(5:6),'y');

% axis Interpreter to latex
h = findall(gcf,'Type','axes'); % An array if you have subplots
set(h, 'TickLabelInterpreter', 'latex')

% Set size and no crop
set(gcf, 'PaperUnits', 'centimeters', 'PaperSize', figsize);
set(gcf, 'PaperUnits', 'normalized', 'PaperPosition', [0, 0, 1, 1]);

% print -dpdf results_handin3.pdf
print -dbmp results_handin3.bmp

